.. _pydl.photoop:

===================================
SDSS Imaging Data  (`pydl.photoop`)
===================================

Introduction
++++++++++++

This is a placeholder for photoop documentation.

API
+++

.. automodapi:: pydl.photoop

.. automodapi:: pydl.photoop.photoobj

.. automodapi:: pydl.photoop.sdssio

.. automodapi:: pydl.photoop.window
